module.exports = defineTest({
	description: 'generates IIFE export with all code and overrides config',
	command: 'rollup -c --no-treeshake'
});
